@@ -1,10 +1,9 @@
 package org.antlr.v4.test.tool;
 
+import org.antlr.v4.gui.TreeTextProvider;
 import org.antlr.v4.runtime.tree.ErrorNode;
 import org.antlr.v4.runtime.tree.Tree;
 import org.antlr.v4.runtime.tree.Trees;
-import org.antlr.v4.gui.TreeTextProvider;
-import org.antlr.v4.tool.GrammarInterpreterRuleContext;
 
 import java.util.Arrays;
 import java.util.List;
@@ -17,10 +16,6 @@ public class InterpreterTreeTextProvider implements TreeTextProvider {
 	public String getText(Tree node) {
 		if ( node==null ) return "null";
 		String nodeText = Trees.getNodeText(node, ruleNames);
-		if ( node instanceof GrammarInterpreterRuleContext) {
-			GrammarInterpreterRuleContext ctx = (GrammarInterpreterRuleContext) node;
-			return nodeText+":"+ctx.getOuterAltNum();
-		}
 		if ( node instanceof ErrorNode) {
 			return "<error "+nodeText+">";
 		}
